==> tecfy_core_package-0.1.36.tar.gz: lib/services/account.service.dart <==
part of tecfy_core_client_package;

class AccountService {
  static Future<bool> init(context) async {
    try {
      await ConfigService.init();
      // await ConfigService.loadConfig();
      if (ConfigService.isLogin) {
        await InitService.afterLoginInit();
        TecfyCoreApp.navigateToDefaultPage(context);
        initFull(context);
        return true;
      } else {
        var isLoginResult = await initFull(context);
        if (isLoginResult) {
          InitService.afterLoginInit();
          TecfyCoreApp.navigateToDefaultPage(context);
          return true;
        } else
          print("initFull retuens false");
      }
      //return true;
    } catch (err) {
      print(
          'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx init account error xxxxxxxxxxxxxxxx');
      print(err);
      // return false;
    }
    print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Go to login');
    AppNavigator.navigateTo(context, () => LoginPage(),
        replaceAll: true, animationType: AnimationTypes.opacity);
    return true;
  }

  Future<OperationResult> login(String username, String password) async {
    try {
      var result = await ApiService.httpPostEx(
          'auth/login', {'Username': username, 'Password': password}, false);
      if (!result.success) {
        print(
            'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  login result XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX');
        print(result);
        print(result.message);
        print(result.errorCodeString);
        print(result.data);
        return result;
      }
      print('================= LOGIN ================');
      print(result.data);
      print(result.data['token']);
      if (result.data['company'] == null ||
          result.data['user']['companyId'] == null ||
          result.data['user']['companyId'].length == 0) {
        result.data['user']['isSuperuser'] = true;
      }
      ConfigService.setValueMap(
          ConfigKeys.user, User.fromJson(result.data['user']).toJson());
      ConfigService.token = result.data['token'];
      ConfigService.setValueMap(ConfigKeys.company, result.data['company']);

      ConfigService.isLogin = true;
      return OperationResult(success: result.success, message: result.message);
    } catch (err) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  error ar login!! XXXXXXXXXXXXXXXXXXXX');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<bool> initFull(context) async {
    try {
      //ConfigService.loadConfig();
    } catch (err) {}
    return ConfigService.token != null && ConfigService.token.isNotEmpty;
    // var u = await FirebaseAuth.instance.currentUser();
    // if (u == null) {
    //   return false;
    // } else {
    //   // load user info from firestore
    //   isAnonymous = u.isAnonymous;
    //   await loadUser(u.uid);
    //   return true;
    // }
  }

  static signout(context) async {
    try {
      var result = await AppNavigator.confirmMessage(context,
          AppLocale.translate(context, 'Are you sure you want to logout?'));
      if (!result) return;

      int pending = await TecfySyncService.getUnpostedCount();
      if (pending > 0) {
        result = await AppNavigator.confirmMessage(
            context, 'You have $pending local items not posted to server!!!!',
            message: AppLocale.translate(
                context, 'Are you sure you want to logout?'));
        if (!result) return;
      }
      ConfigService.resetConfig();

      await DatabaseService.deleteDatabaseFile();
      await DatabaseService.init();
      AppNavigator.navigateTo(context, () => LoginPage(),
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err) {
      print(err);
      AppNavigator.showMessage(context, 'Error', type: MessageType.error);
    }
  }

  static Future<OperationResult> loadUser(String id) async {
    try {
      // var userDataMap =
      //     await Firestore.instance.collection('users').document(id).get();

      // user = User.fromJson(id, userDataMap.data);
      //ConfigService.saveConfig();

      // await prefs.commit();
      return OperationResult(success: true);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<bool>> isLogin(context) async {
    if (ConfigService.isLogin)
      return OperationResult(success: true, data: true);
    await Future.delayed(Duration(milliseconds: 100));

    return OperationResult(success: true, data: false);
  }
}

==> tecfy_core_package-0.1.42.tar.gz: lib/services/account.service.dart <==
part of tecfy_core_client_package;

class AccountService {
  static Future<bool> init(context) async {
    try {
      await ConfigService.init();
      // await ConfigService.loadConfig();
      if (ConfigService.isLogin) {
        await InitService.afterLoginInit();
        TecfyCoreApp.navigateToDefaultPage(context);
        initFull(context);
        return true;
      } else {
        var isLoginResult = await initFull(context);
        if (isLoginResult) {
          InitService.afterLoginInit();
          TecfyCoreApp.navigateToDefaultPage(context);
          return true;
        } else
          print("initFull retuens false");
      }
      //return true;
    } catch (err) {
      print(
          'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx init account error xxxxxxxxxxxxxxxx');
      print(err);
      // return false;
    }
    print('XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Go to login');
    AppNavigator.navigateTo(context, () => LoginPage(),
        replaceAll: true, animationType: AnimationTypes.opacity);
    return true;
  }

  Future<OperationResult> login(String username, String password) async {
    try {
      var result = await ApiService.httpPostEx(
          'auth/login', {'Username': username, 'Password': password}, false);
      if (!result.success) {
        print(
            'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  login result XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX');
        print(result);
        print(result.message);
        print(result.errorCodeString);
        print(result.data);
        return result;
      }
      print('================= LOGIN ================');
      print(result.data);
      print(result.data['token']);
      if (result.data['company'] == null ||
          result.data['user']['companyId'] == null ||
          result.data['user']['companyId'].length == 0) {
        result.data['user']['isSuperuser'] = true;
      }
      ConfigService.setValueMap(
          ConfigKeys.user, User.fromJson(result.data['user']).toJson());
      ConfigService.token = result.data['token'];
      ConfigService.setValueMap(ConfigKeys.company, result.data['company']);

      ConfigService.isLogin = true;
      return OperationResult(success: result.success, message: result.message);
    } catch (err) {
      print(
          'XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  error ar login!! XXXXXXXXXXXXXXXXXXXX');
      print(err);
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<bool> initFull(context) async {
    try {
      //ConfigService.loadConfig();
    } catch (err) {}
    return ConfigService.token != null && ConfigService.token.isNotEmpty;
    // var u = await FirebaseAuth.instance.currentUser();
    // if (u == null) {
    //   return false;
    // } else {
    //   // load user info from firestore
    //   isAnonymous = u.isAnonymous;
    //   await loadUser(u.uid);
    //   return true;
    // }
  }

  static signout(context) async {
    try {
      var result = await AppNavigator.confirmMessage(context,
          AppLocale.translate(context, 'Are you sure you want to logout?'));
      if (!result) return;

      int pending = await TecfySyncService.getUnpostedCount();
      if (pending > 0) {
        result = await AppNavigator.confirmMessage(
            context, 'You have $pending local items not posted to server!!!!',
            message: AppLocale.translate(
                context, 'Are you sure you want to logout?'));
        if (!result) return;
      }
      await ConfigService.setValueString('Entity', null);
      await ConfigService.resetConfig();

      await DatabaseService.deleteDatabaseFile();
      await DatabaseService.init();
      AppNavigator.navigateTo(context, () => LoginPage(),
          replaceAll: true, animationType: AnimationTypes.opacity);
    } catch (err) {
      print(err);
      AppNavigator.showMessage(context, 'Error', type: MessageType.error);
    }
  }

  static Future<OperationResult> loadUser(String id) async {
    try {
      // var userDataMap =
      //     await Firestore.instance.collection('users').document(id).get();

      // user = User.fromJson(id, userDataMap.data);
      //ConfigService.saveConfig();

      // await prefs.commit();
      return OperationResult(success: true);
    } catch (err) {
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<bool>> isLogin(context) async {
    if (ConfigService.isLogin)
      return OperationResult(success: true, data: true);
    await Future.delayed(Duration(milliseconds: 100));

    return OperationResult(success: true, data: false);
  }
}
